@@ -51,6 +51,7 @@ private:
 class CSound
 {
 public:
+	// the p_addr_t needs to agree with CSound::getAudioDataSize()'s implementation too
 	typedef TPoolFile<sample_pos_t,uint64_t> PoolFile_t;
 
 	CSound();
@@ -369,14 +370,18 @@ public:
 	void insertCue(size_t index,const string &name,const sample_pos_t time,const bool isAnchored);
 	void removeCue(size_t index);
 	void clearCues();
+	void enableCueAdjustmentsOnSpaceChanges(bool enabled);
 
 	static size_t __default_cue_index;
 	bool containsCue(const string &name,size_t &index=__default_cue_index) const;
 		// these following find methods return true if something is found else false
 	bool findCue(const sample_pos_t time,size_t &index) const;
 	bool findNearestCue(const sample_pos_t time,size_t &index,sample_pos_t &distance) const; // finds the cue nearest to the given time
-	bool findPrevCue(const sample_pos_t time,size_t &index) const; // finds the previous cue in time at the given time
-	bool findNextCue(const sample_pos_t time,size_t &index) const; // finds the following cue in time at the given time
+	bool findPrevCue(const sample_pos_t time,size_t &index) const; // finds the previous cue in time at the cue with the given time (false if none is found)
+	bool findNextCue(const sample_pos_t time,size_t &index) const; // finds the following cue in time at the cue with the given time (false if none is found)
+
+	bool findPrevCueInTime(const sample_pos_t time,size_t &index) const; // finds the previous cue in time from the given time (false if none is found)
+	bool findNextCueInTime(const sample_pos_t time,size_t &index) const; // finds the next cue in time from the given time (false if none is found)
 
 	const string getUnusedCueName(const string &prefix="noname") const;
 
@@ -489,6 +494,7 @@ private:
 	typedef TPoolAccesser<RCue,PoolFile_t> CCuePoolAccesser;
 	CCuePoolAccesser *cueAccesser;
 	map<sample_pos_t,size_t> cueIndex; // index into cueAccesser by time
+	bool adjustCuesOnSpaceChanges;
 
 	void adjustCues(const sample_pos_t pos1,const sample_pos_t pos2);
 	void createCueAccesser();
