@@ -28,6 +28,7 @@
 
 #include "../backend/CActionParameters.h"
 #include "../backend/Edits/CCueAction.h"
+#include "../backend/Edits/CSelectionEdit.h"
 
 #include <string>
 #include <algorithm>
@@ -114,6 +115,7 @@ private:
 
 	FXFont *font;
 
+	#define NIL_CUE_INDEX (0xffffffff)
 	size_t cueClicked; // the index of the cue clicked on holding the value between the click event and the menu item event
 	int cueClickedOffset; // used when dragging cues to know how far from the middle a cue was clicked
 	sample_pos_t origCueClickedTime;
@@ -121,13 +123,14 @@ private:
 	sample_pos_t origStopPosition; // stop position before drag cue start (for undo purposes)
 	sample_pos_t addCueTime; // the time in the audio where the mouse was clicked to add a cue if that's what they choose
 
-	size_t focusedCueIndex; // 0xffff,ffff if none focused
+	size_t focusedCueIndex; // NIL_CUE_INDEX if none focused
 	sample_pos_t focusedCueTime;
 
 	FXPopupHint *dragCueHint;
 
 	bool draggingSelectionToo; // true when a cue to be dragged was on the start or stop position
 
+	CSelectionEditPositionFactory *selectionEditPositionFactory;
 	CMoveCueActionFactory *moveCueActionFactory;
 	CRemoveCueActionFactory *removeCueActionFactory;
 };
@@ -325,6 +328,7 @@ FXWaveRuler::FXWaveRuler(FXComposite *p,FXRezWaveView *_parent,CLoadedSound *_lo
 
 	dragCueHint(new FXPopupHint(p->getApp())),
 
+	selectionEditPositionFactory(NULL),
 	moveCueActionFactory(NULL),
 	removeCueActionFactory(NULL)
 {
@@ -337,11 +341,14 @@ FXWaveRuler::FXWaveRuler(FXComposite *p,FXRezWaveView *_parent,CLoadedSound *_lo
 	d.size=65;
 	font=new FXFont(getApp(),d);
 
-	focusedCueIndex=0xffffffff;
+	cueClicked=NIL_CUE_INDEX;
+
+	focusedCueIndex=NIL_CUE_INDEX;
 	focusNextCue(); // to make it focus the first one if there is one
 
 	dragCueHint->create();
 
+	selectionEditPositionFactory=new CSelectionEditPositionFactory;
 	moveCueActionFactory=new CMoveCueActionFactory;
 	removeCueActionFactory=new CRemoveCueActionFactory;
 }
@@ -393,11 +400,7 @@ long FXWaveRuler::onPaint(FXObject *object,FXSelector sel,void *ptr)
 		e=lastX;
 
 	dc.setForeground(FXRGB(20,20,20));
-#if REZ_FOX_VERSION<10117
-	dc.setTextFont(font);
-#else
-	dc.setFont(font);
-#endif
+	dc.compat_setFont(font);
 	for(FXint x=s;x<=e;x++)
 	{
 		if((x%LABEL_TICK_FREQ)==0)
@@ -434,7 +437,7 @@ long FXWaveRuler::onPaint(FXObject *object,FXSelector sel,void *ptr)
 			dc.drawLine(cueXPosition,height-1,cueXPosition,CUE_Y);
 			dc.drawLine(cueXPosition+1,height-4,cueXPosition+1,CUE_Y-1);
 
-			if(hasFocus() && focusedCueIndex!=0xffffffff && focusedCueTime==sound->getCueTime(t))
+			if(hasFocus() && focusedCueIndex!=NIL_CUE_INDEX && focusedCueTime==sound->getCueTime(t))
 			{	// draw focus rectangle
 				const int textWidth=font->getTextWidth(cueName.data(),cueName.size());
 				const int textHeight=font->getTextHeight(cueName.data(),cueName.size());
@@ -454,7 +457,7 @@ long FXWaveRuler::onPaint(FXObject *object,FXSelector sel,void *ptr)
 size_t FXWaveRuler::getClickedCue(FXint x,FXint y)
 {
 	const size_t cueCount=sound->getCueCount();
-	size_t cueClicked=cueCount;
+	size_t cueClicked=NIL_CUE_INDEX;
 	if(cueCount>0)
 	{
 		// go in reverse order so that the more recent one created can be removed first
@@ -490,7 +493,7 @@ long FXWaveRuler::onPopupMenu(FXObject *object,FXSelector sel,void *ptr)
 	FXEvent *event=(FXEvent*)ptr;
 
 	// see if any cue was clicked on
-	cueClicked=getClickedCue(event->win_x,event->win_y);
+	cueClicked=getClickedCue(event->win_x,event->win_y); // setting data member for onSetPositionToCue's sake
 
 	if(cueClicked<sound->getCueCount())
 	{
@@ -539,8 +542,8 @@ long FXWaveRuler::onPopupMenu(FXObject *object,FXSelector sel,void *ptr)
 		getApp()->runModalWhileShown(&gotoMenu);
 	}
 
-
-	return(0);
+	cueClicked=NIL_CUE_INDEX;
+	return 0;
 }
 
 long FXWaveRuler::onFindStartPosition(FXObject *object,FXSelector sel,void *ptr)
@@ -764,7 +767,6 @@ long FXWaveRuler::onLeftBtnRelease(FXObject *object,FXSelector sel,void *ptr)
 	FXEvent* event=(FXEvent*)ptr;
 	if(event->click_count==1) //	<-- single click
 	{
-
 		if(cueClicked<sound->getCueCount() && sound->getCueTime(cueClicked)!=origCueClickedTime)
 		{	// was dragging a cue around
 			const sample_pos_t newCueTime=sound->getCueTime(cueClicked);
@@ -790,8 +792,31 @@ long FXWaveRuler::onLeftBtnRelease(FXObject *object,FXSelector sel,void *ptr)
 		if(cueClicked<sound->getCueCount())
 			return onEditCue(object,sel,(void *)cueClicked);
 		else
-			return onShowCueList(object,sel,ptr);
+		{ // clicking not on a cue.. change selection to be that which is between the two nearest cues (or to start or end if there isn't any near on that side)
+			size_t index;
+			sample_pos_t startPos=0;
+			sample_pos_t stopPos=sound->getLength()-1;
+			sample_pos_t clickedPos=parent->waveScrollArea->getCueTimeFromX(event->win_x);
+
+			if(sound->findPrevCueInTime(clickedPos,index))
+				startPos=sound->getCueTime(index);
+
+			if(sound->findNextCueInTime(clickedPos,index))
+				stopPos=sound->getCueTime(index)-1; // select from the position AT the start cue to one less sample prior to the next cue
+
+			if(stopPos<startPos) // safety
+				stopPos=startPos;
+
+			// could make this a real action so that it could be undone
+			CActionParameters actionParameters(NULL);
+			selectionEditPositionFactory->selectStart=startPos;
+			selectionEditPositionFactory->selectStop=stopPos;
+			selectionEditPositionFactory->performAction(loadedSound,&actionParameters,false);
+			parent->updateFromEdit();
+		}
 	}
+
+	cueClicked=NIL_CUE_INDEX;
 	return 0;
 }
 
@@ -850,7 +875,7 @@ long FXWaveRuler::onKeyPress(FXObject *object,FXSelector sel,void *ptr)
 		if(focusedCueIndex>=sound->getCueCount())
 			focusLastCue(); // find last cue if we just deleted what was the last cue
 
-		if(focusedCueIndex!=0xffffffff)
+		if(focusedCueIndex!=NIL_CUE_INDEX)
 			parent->waveScrollArea->centerTime(focusedCueTime);
 		parent->waveScrollArea->redraw();
 		update();
@@ -870,7 +895,7 @@ long FXWaveRuler::onKeyPress(FXObject *object,FXSelector sel,void *ptr)
 			sound->setCueTime(cueClicked,origCueClickedTime);
 			dragCueHint->hide();
 			parent->waveScrollArea->stopAutoScroll();
-			cueClicked=sound->getCueCount();
+			cueClicked=NIL_CUE_INDEX;
 			update();
 			parent->waveScrollArea->redraw();
 			return 1;
@@ -879,7 +904,7 @@ long FXWaveRuler::onKeyPress(FXObject *object,FXSelector sel,void *ptr)
 		return 0;
 	}
 
-	if(focusedCueIndex!=0xffffffff)
+	if(focusedCueIndex!=NIL_CUE_INDEX)
 	{
 		parent->waveScrollArea->centerTime(focusedCueTime);
 		update();
@@ -891,11 +916,11 @@ long FXWaveRuler::onKeyPress(FXObject *object,FXSelector sel,void *ptr)
 
 void FXWaveRuler::focusNextCue()
 {
-	if(focusedCueIndex==0xffffffff)
+	if(focusedCueIndex==NIL_CUE_INDEX)
 	{
 		sample_pos_t dummy;
 		if(!sound->findNearestCue(0,focusedCueIndex,dummy))
-			focusedCueIndex=0xffffffff;
+			focusedCueIndex=NIL_CUE_INDEX;
 		else
 			focusedCueTime=sound->getCueTime(focusedCueIndex);
 	}
@@ -904,20 +929,20 @@ void FXWaveRuler::focusNextCue()
 		if(sound->findNextCue(focusedCueTime,focusedCueIndex))
 			focusedCueTime=sound->getCueTime(focusedCueIndex);
 		else
-			focusedCueIndex=0xffffffff;
+			focusedCueIndex=NIL_CUE_INDEX;
 	}
 }
 
 void FXWaveRuler::focusPrevCue()
 {
-	if(focusedCueIndex==0xffffffff)
+	if(focusedCueIndex==NIL_CUE_INDEX)
 		focusNextCue(); // would implement the same thing here, so just call it
 	else
 	{
 		if(sound->findPrevCue(focusedCueTime,focusedCueIndex))
 			focusedCueTime=sound->getCueTime(focusedCueIndex);
 		else
-			focusedCueIndex=0xffffffff;
+			focusedCueIndex=NIL_CUE_INDEX;
 	}
 }
 
@@ -925,7 +950,7 @@ void FXWaveRuler::focusFirstCue()
 {
 	sample_pos_t dummy;
 	if(!sound->findNearestCue(0,focusedCueIndex,dummy))
-		focusedCueIndex=0xffffffff;
+		focusedCueIndex=NIL_CUE_INDEX;
 	else
 		focusedCueTime=sound->getCueTime(focusedCueIndex);
 }
@@ -934,7 +959,7 @@ void FXWaveRuler::focusLastCue()
 {
 	sample_pos_t dummy;
 	if(!sound->findNearestCue(sound->getLength()-1,focusedCueIndex,dummy))
-		focusedCueIndex=0xffffffff;
+		focusedCueIndex=NIL_CUE_INDEX;
 	else
 		focusedCueTime=sound->getCueTime(focusedCueIndex);
 }
